@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,6 +55,7 @@ import java.util.Set;
 import javax.management.AttributeNotFoundException;
 import javax.management.InstanceNotFoundException;
 import javax.management.IntrospectionException;
+import javax.management.JMException;
 import javax.management.MBeanException;
 import javax.management.MBeanInfo;
 import javax.management.MBeanOperationInfo;
@@ -64,12 +65,17 @@ import javax.management.ObjectName;
 import javax.management.ReflectionException;
 import com.openexchange.admin.console.AdminParser.NeededQuadState;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
+import com.openexchange.threadpool.ThreadPoolInformationMBean;
 
 public class StatisticTools extends AbstractJMXTools {
 
     private static final char OPT_STATS_SHORT = 'x';
 
     private static final String OPT_STATS_LONG = "xchangestats";
+    
+    private static final char OPT_TPSTATS_SHORT = 'p';
+    
+    private static final String OPT_TPSTATS_LONG = "threadpoolstats";
 
     private static final char OPT_RUNTIME_STATS_SHORT = 'r';
 
@@ -100,6 +106,8 @@ public class StatisticTools extends AbstractJMXTools {
     private static final String OPT_DOOPERATIONS_STATS_LONG = "dooperation";
     
     private CLIOption xchangestats = null;
+    
+    private CLIOption threadpoolstats = null;
 
     private CLIOption runtimestats = null;
 
@@ -114,6 +122,7 @@ public class StatisticTools extends AbstractJMXTools {
     private CLIOption showoperation = null;
 
     private CLIOption dooperation = null;
+    private CLIOption sessionStats = null;
     
     public static void main(final String args[]) {
         final StatisticTools st = new StatisticTools();
@@ -121,7 +130,7 @@ public class StatisticTools extends AbstractJMXTools {
     }
 
     @Override
-    protected void furtherOptionsHandling(final AdminParser parser, final HashMap<String, String[]> env) throws InterruptedException, IOException, InstanceNotFoundException, AttributeNotFoundException, IntrospectionException, MBeanException, ReflectionException, MalformedObjectNameException, InvalidDataException {
+    protected void furtherOptionsHandling(final AdminParser parser, final HashMap<String, String[]> env) throws JMException, InterruptedException, IOException, InstanceNotFoundException, AttributeNotFoundException, IntrospectionException, MBeanException, ReflectionException, MalformedObjectNameException, InvalidDataException {
         boolean admin = false;
         if (null != parser.getOptionValue(this.admindaemonstats)) {
             admin = true;
@@ -132,6 +141,11 @@ public class StatisticTools extends AbstractJMXTools {
             showOXData(initConnection, admin);
             count++;
         }
+        if (null != parser.getOptionValue(this.threadpoolstats)) {
+            final MBeanServerConnection initConnection = initConnection(admin, env);
+            showThreadPoolData(initConnection);
+            count++;
+        }
         if (null != parser.getOptionValue(this.runtimestats)) {
             if (0 == count) {
                 final MBeanServerConnection initConnection = initConnection(admin, env);
@@ -156,10 +170,19 @@ public class StatisticTools extends AbstractJMXTools {
             count++;
 
         }
+        if (null != parser.getOptionValue(this.sessionStats)) {
+            if (0 == count) {
+                final MBeanServerConnection initConnection = initConnection(admin, env);
+                System.out.print(getStats(initConnection, "com.openexchange.sessiond", "name", "SessionD Toolkit"));
+                count++;
+            }
+        }
         if (null != parser.getOptionValue(this.allstats)) {
             if (0 == count) {
                 final MBeanServerConnection initConnection = initConnection(admin, env);
                 showOXData(initConnection, admin);
+                System.out.print(getStats(initConnection, "com.openexchange.sessiond", "name", "SessionD Toolkit"));
+                showThreadPoolData(initConnection);
                 System.out.print(getStats(initConnection, "com.sun.management.UnixOperatingSystem"));
                 System.out.print(getStats(initConnection, "sun.management.RuntimeImpl"));
                 showMemoryPoolData(initConnection);
@@ -191,7 +214,7 @@ public class StatisticTools extends AbstractJMXTools {
         if (0 == count) {
             System.err.println(new StringBuilder("No option selected (").append(OPT_STATS_LONG).append(", ")
                     .append(OPT_RUNTIME_STATS_LONG).append(", ").append(OPT_OS_STATS_LONG).append(", ")
-                    .append(OPT_THREADING_STATS_LONG).append(", ").append(OPT_ALL_STATS_LONG).append(")"));
+                    .append(OPT_THREADING_STATS_LONG).append(", ").append(OPT_ALL_STATS_LONG).append(", sessionstats)"));
             parser.printUsage();
         } else if (count > 1) {
             System.err.println("More than one of the stat options given. Using the first one only");
@@ -201,6 +224,7 @@ public class StatisticTools extends AbstractJMXTools {
     @Override
     protected void setFurtherOptions(final AdminParser parser) {
         this.xchangestats = setShortLongOpt(parser, OPT_STATS_SHORT, OPT_STATS_LONG, "shows Open-Xchange stats", false, NeededQuadState.notneeded);
+        this.threadpoolstats = setShortLongOpt(parser, OPT_TPSTATS_SHORT, OPT_TPSTATS_LONG, "shows OX-Server threadpool stats", false, NeededQuadState.notneeded);
         this.runtimestats = setShortLongOpt(parser, OPT_RUNTIME_STATS_SHORT, OPT_RUNTIME_STATS_LONG, "shows Java runtime stats", false, NeededQuadState.notneeded);
         this.osstats = setShortLongOpt(parser, OPT_OS_STATS_SHORT, OPT_OS_STATS_LONG, "shows operating system stats", false, NeededQuadState.notneeded);
         this.threadingstats = setShortLongOpt(parser, OPT_THREADING_STATS_SHORT, OPT_THREADING_STATS_LONG, "shows threading stats", false, NeededQuadState.notneeded);
@@ -208,6 +232,7 @@ public class StatisticTools extends AbstractJMXTools {
         this.admindaemonstats = setShortLongOpt(parser, OPT_ADMINDAEMON_STATS_SHORT, OPT_ADMINDAEMON_STATS_LONG, "shows stats for the admin instead of the groupware", false, NeededQuadState.notneeded);
         this.showoperation = setShortLongOpt(parser, OPT_SHOWOPERATIONS_STATS_SHORT, OPT_SHOWOPERATIONS_STATS_LONG, "shows the operations for the registered beans", false, NeededQuadState.notneeded);
         this.dooperation = setShortLongOpt(parser, OPT_DOOPERATIONS_STATS_SHORT, OPT_DOOPERATIONS_STATS_LONG, "operation", "Syntax is <canonical object name (the first part from showoperatons)>!<operationname>", false);
+        this.sessionStats = setShortLongOpt(parser, 'i', "sessionstats", "shows the statistics of the session container", false, NeededQuadState.notneeded);
     }
 
     private void showMemoryPoolData(final MBeanServerConnection mbc) throws InstanceNotFoundException, AttributeNotFoundException, IntrospectionException, MBeanException, ReflectionException, IOException {
@@ -231,6 +256,10 @@ public class StatisticTools extends AbstractJMXTools {
         }
     }
     
+    private void showThreadPoolData(MBeanServerConnection mbc) throws InstanceNotFoundException, AttributeNotFoundException, IntrospectionException, MBeanException, ReflectionException, IOException {
+        System.out.print(getStats(mbc, ThreadPoolInformationMBean.THREAD_POOL_DOMAIN + ".internal.ThreadPoolInformation"));
+    }
+    
     @SuppressWarnings("unchecked")
     private void showOperations(final MBeanServerConnection mbc) throws IOException, InstanceNotFoundException, IntrospectionException, ReflectionException {
         final Set<ObjectName> queryNames = mbc.queryNames(null, null);
