@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,15 +49,14 @@
 
 package com.openexchange.admin.rmi.impl;
 
+import static com.openexchange.java.Autoboxing.i;
 import java.io.File;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.rmi.RemoteException;
 import java.util.Arrays;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-
 import com.openexchange.admin.rmi.OXUtilInterface;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.Database;
@@ -90,7 +89,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         basicauth = new BasicAuthenticator();
     }
 
-    public Filestore registerFilestore(final Filestore fstore, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public Filestore registerFilestore(final Filestore fstore, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(fstore);
         } catch (final InvalidDataException e1) {            
@@ -140,7 +140,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
 
     }
 
-    public void changeFilestore(final Filestore fstore, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public void changeFilestore(final Filestore fstore, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(fstore);
         } catch (final InvalidDataException e1) {            
@@ -162,7 +163,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         oxutil.changeFilestore(fstore);
     }
 
-    public Filestore[] listFilestore(final String search_pattern, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public Filestore[] listFilestore(final String search_pattern, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(search_pattern);
         } catch (final InvalidDataException e1) {            
@@ -184,7 +186,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         return listFilestore("*", auth);
     }
     
-    public void unregisterFilestore(final Filestore store, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public void unregisterFilestore(final Filestore store, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(store);
             doNullCheck(store.getId());
@@ -208,7 +211,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
     }
 
     
-    public MaintenanceReason createMaintenanceReason(final MaintenanceReason reason, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public MaintenanceReason createMaintenanceReason(final MaintenanceReason reason, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(reason);
         } catch (final InvalidDataException e1) {            
@@ -229,7 +233,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         return  new MaintenanceReason(oxutil.createMaintenanceReason(reason));
     }
 
-    public MaintenanceReason[] listMaintenanceReasons(final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException {
+    public MaintenanceReason[] listMaintenanceReasons(Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException {
+        auth = auth == null ? new Credentials("","") : auth;
         basicauth.doAuthentication(auth);
 
         return oxutil.getAllMaintenanceReasons();
@@ -253,7 +258,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         return listMaintenanceReason("*", auth);
     }
     
-    public void createDatabase(final Database db, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public void createDatabase(final Database db, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try{
             doNullCheck(db);
         } catch (final InvalidDataException e1) {            
@@ -281,7 +287,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         oxutil.createDatabase(db);
     }
 
-    public void deleteDatabase(final Database db, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public void deleteDatabase(final Database db, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try{
             doNullCheck(db);
         } catch (final InvalidDataException e1) {            
@@ -304,7 +311,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         }
     }
 
-    public Database registerDatabase(final Database db, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public Database registerDatabase(final Database db, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try{
             doNullCheck(db);
         } catch (final InvalidDataException e1) {            
@@ -367,7 +375,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
     }
 
    
-    public Server registerServer(final Server srv, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public Server registerServer(final Server srv, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try{
             doNullCheck(srv);
             doNullCheck(srv.getName());
@@ -394,31 +403,29 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         return sr;
     }
 
-    public void unregisterDatabase(final Database database, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public void unregisterDatabase(final Database database, final Credentials auth) throws StorageException, InvalidCredentialsException, InvalidDataException {
         try{
             doNullCheck(database);
-        } catch (final InvalidDataException e1) {            
-            log.error("Invalid data sent by client!", e1);
-            throw e1;
+        } catch (final InvalidDataException e) {            
+            log.error("Invalid data sent by client!", e);
+            throw e;
         }
-        
-        basicauth.doAuthentication(auth);
+        basicauth.doAuthentication(null == auth ? new Credentials("","") : auth);
 
         log.debug(database);
-
         setIdOrGetIDFromNameAndIdObject(null, database);
-        if (!tool.existsDatabase(database.getId())) {
+        if (!tool.existsDatabase(i(database.getId()))) {
             throw new InvalidDataException("No such database " + database);
         }
-        if (tool.poolInUse(database.getId())) {
+        if (tool.poolInUse(i(database.getId()))) {
             throw new StorageException("Pool is in use " + database);
         }
 
-        oxutil.unregisterDatabase(database.getId());
+        oxutil.unregisterDatabase(i(database.getId()), tool.isMasterDatabase(i(database.getId())));
     }
 
-  
-    public void unregisterServer(final Server server, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public void unregisterServer(final Server server, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try{
             doNullCheck(server);
         } catch (final InvalidDataException e1) {            
@@ -442,7 +449,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
     }
 
     
-    public Database[] listDatabase(final String search_pattern, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public Database[] listDatabase(final String search_pattern, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try{
             doNullCheck(search_pattern);
         } catch (final InvalidDataException e1) {            
@@ -464,7 +472,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         return listDatabase("*", auth);
     }
     
-    public Server[] listServer(final String search_pattern, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public Server[] listServer(final String search_pattern, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try{
             doNullCheck(search_pattern);
         } catch (final InvalidDataException e1) {            
@@ -486,7 +495,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         return listServer("*", auth);
     }
     
-    public void changeDatabase(final Database db, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public void changeDatabase(final Database db, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(db);
         } catch (final InvalidDataException e1) {            
@@ -517,7 +527,8 @@ public class OXUtil extends OXCommonImpl implements OXUtilInterface {
         oxutil.changeDatabase(db);
     }
 
-    public void deleteMaintenanceReason(final MaintenanceReason[] reasons, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public void deleteMaintenanceReason(final MaintenanceReason[] reasons, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck((Object[])reasons);
         } catch (final InvalidDataException e1) {            
